==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/order_total/ot_gambioultra.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ot_gambioultra.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_DESCRIPTION' => 'Artikelweiser Versandkostenzuschlag',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_DESTINATION_DESC' => 'Versandkostenzuschlag für Bestellungen, die an diesen Ort versandt werden.',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_DESTINATION_TITLE' => 'Versandkostenzuschlag für Zonen berechnen',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_DETAILS_DESC' => 'Zuschläge der Artikel einzeln auflisten',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_DETAILS_TITLE' => 'Details zum Versandkostenzuschlag',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_OUTPUT_NAME_DESC' => 'Bezeichnung des Zuschlages',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_OUTPUT_NAME_TITLE' => 'Bezeichnung',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_SORT_ORDER_DESC' => 'Anzeigereihenfolge.',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_SORT_ORDER_TITLE' => 'Sortierreihenfolge',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_STATUS_DESC' => 'Möchten Sie den artikelweisen Versandkostenzuschlag aktivieren?',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_STATUS_TITLE' => 'Versandkostenzuschlag anzeigen',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_TAX_CLASS_DESC' => 'Folgende Steuerklasse für den Versandkostenzuschlag verwenden.',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_TITLE' => 'Versandkostenzuschlag'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/order_total/ot_gambioultra.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ot_gambioultra.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_DESCRIPTION' => 'Artikelweiser Versandkostenzuschlag',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_DESTINATION_DESC' => 'Versandkostenzuschlag für Bestellungen, die an diesen Ort versandt werden.',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_DESTINATION_TITLE' => 'Versandkostenzuschlag für Zonen berechnen',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_DETAILS_DESC' => 'Zuschläge der Artikel einzeln auflisten',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_DETAILS_TITLE' => 'Details zum Versandkostenzuschlag',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_OUTPUT_NAME_DESC' => 'Bezeichnung des Zuschlages',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_OUTPUT_NAME_TITLE' => 'Bezeichnung',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_SORT_ORDER_DESC' => 'Anzeigereihenfolge.',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_SORT_ORDER_TITLE' => 'Sortierreihenfolge',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_STATUS_DESC' => 'Möchtest du den artikelweisen Versandkostenzuschlag aktivieren?',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_STATUS_TITLE' => 'Versandkostenzuschlag anzeigen',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_TAX_CLASS_DESC' => 'Folgende Steuerklasse für den Versandkostenzuschlag verwenden.',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_ORDER_TOTAL_GAMBIOULTRA_TITLE' => 'Versandkostenzuschlag'
);
